Name:           meataxe
Version:        2.4.24
Release:        18%{?dist}
Summary:        Matrix representations over finite fields

License:        GPLv2+
URL:            http://www.math.rwth-aachen.de/~MTX/
Source0:        http://www.math.rwth-aachen.de/~MTX/%{name}-%{version}.tar.gz
# These man pages were written by Jerry James <loganjerry@gmail.com> using
# text taken from the sources.  Therefore, these pages have the same copyright
# and license as the source files.
Source1:        %{name}-man.tar.xz
# Template for an environment modules file
Source2:        %{name}.module.in
# This patch causes a shared library to be built instead of a static library,
# and to link all of the binaries against the shared library.  Upstream is
# not interested in building a shared library.
Patch0:         %{name}-shared.patch
# File I/O only works as intended on little endian 32-bit architectures
Patch1:         %{name}-endian.patch

BuildRequires:  doxygen-latex
BuildRequires:  gcc
BuildRequires:  ghostscript
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
Requires:       environment(modules)

%description
The MeatAxe is a set of programs for working with matrix representations
over finite fields.  Permutation representations are supported to some
extent, too.

%package libs
Summary:        Library of matrix representations over finite fields

%description libs
This package contains the MeatAxe library, which provides functions for
working with matrix representations over finite fields.  Permutation
representations are supported to some extent, too.

%package devel
Summary:        Header files and libraries for MeatAxe development
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
Provides:       bundled(jquery)

%description devel
This package contains the header files and library links for building
applications that use the MeatAxe library.

%prep
%setup -q -c
%setup -q -T -D -a 1
%patch0
%patch1

# Set up the configuration
sed -e "s|^MTXLIB=.*|MTXLIB=%{_tmppath}/|" \
    -e "s|^MTXBIN=.*|MTXBIN=%{_libdir}/%{name}/bin|" \
    -e "s|^CFLAGS1=.*|CFLAGS1=-fsigned-char $RPM_OPT_FLAGS|" \
    Makefile.conf.dist > Makefile.conf

# Let Doxygen find standard header files
sed -ri \
    "s|^(INCLUDE_PATH.*=)|\1 %{_includedir} `echo /usr/lib/gcc/*/*/include`|" \
    etc/Doxyfile

# Let us see compiler warnings
sed -i 's|@\$(CC)|\$(CC)|' Makefile

%build
make %{?_smp_mflags} VERSION=%{version} LFLAGS1="$RPM_LD_FLAGS"
make %{?_smp_mflags} rebuild-doc

%install
# Install the binaries
mkdir -p %{buildroot}%{_libdir}/%{name}/bin
install -m 0755 bin/* -p %{buildroot}%{_libdir}/%{name}/bin
rm -f %{buildroot}%{_libdir}/%{name}/bin/mk.dir

# Install the environment modules file
mkdir -p %{buildroot}%{_datadir}/modulefiles
sed 's|@LIBDIR@|'%{_libdir}/%{name}'|' \
  < %{SOURCE2} > %{buildroot}%{_datadir}/modulefiles/%{name}-%{_arch}

# Install the libraries
cp -dp tmp/libmtx.so* %{buildroot}%{_libdir}
chmod 0755 %{buildroot}%{_libdir}/libmtx.so.%{version}

# Install the header
mkdir -p %{buildroot}%{_includedir}
cp -p src/meataxe.h %{buildroot}%{_includedir}

# Install the man pages
mkdir -p %{buildroot}%{_mandir}/man1
cd man
for m in *.1; do
  sed "s/@VERSION@/%{version}/" $m > %{buildroot}%{_mandir}/man1/$m
  touch -r $m %{buildroot}%{_mandir}/man1/$m
done

%check
make check

%ldconfig_scriptlets libs

%files
%{_datadir}/modulefiles/%{name}-%{_arch}
%{_libdir}/%{name}/
%{_mandir}/man1/*

%files libs
%doc README
%license COPYING
%{_libdir}/libmtx.so.*

%files devel
%doc doc
%{_includedir}/meataxe.h
%{_libdir}/libmtx.so

%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.24-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.24-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.24-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.24-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.24-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.24-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jan 6 2016 Orion Poplawski <orion@cora.nwra.com> - 2.4.24-12
- Require environment(modules), install into generic modulefiles location

* Sat Nov 14 2015 Jerry James <loganjerry@gmail.com> - 2.4.24-11
- Use license macro
- Note bundled jquery

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.24-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.24-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jun 27 2014 Jerry James <loganjerry@gmail.com> - 2.4.24-8
- Build with -fsigned-char to fix FTBFS on aarch64

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.24-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.24-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue May 21 2013 Jerry James <loganjerry@gmail.com> - 2.4.24-5
- Use environment-modules to hide the binaries (bz 962077)
- Use _tmppath for dynamically generated arithmetic tables
- BR doxygen-latex and ghostscript instead of doxygen for better results

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.24-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.24-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 28 2012 Jerry James <loganjerry@gmail.com> - 2.4.24-2
- Enable verbose build
- Fix binary and library permissions

* Fri Jan  6 2012 Jerry James <loganjerry@gmail.com> - 2.4.24-1
- Initial RPM
